Learn R Programming

manifold (version 0.1.2)

distance.Euclidean: Geodesic distance

Description

Geodesic distance

Usage

# S3 method for Euclidean
distance(mfd, X, Y, ...)

distance(mfd, X, Y, ...)

# S3 method for L2 distance(mfd, X, Y, ...)

# S3 method for HS distance(mfd, X, Y, ...)

# S3 method for Dens distance(mfd, X, Y, ...)

# S3 method for SO distance(mfd, X, Y, ...)

# S3 method for LogEu distance(mfd, X, Y, assumeLogRep = FALSE, ...)

# S3 method for AffInv distance(mfd, X, Y, ...)

# S3 method for Sphere distance(mfd, X, Y, ...)

Value

A vector with n entries containing the distances between pairs of points

Arguments

mfd

A manifold object created by createM

X, Y

Matrices with n columns. The distance between each pair of columns is calculated. If either X or Y is a vector then it is recycled.

...

Passed into specific methods

assumeLogRep

Whether to assume the input are already the representations under the logarithm map

Methods (by class)

  • distance(Euclidean): Method

  • distance(L2): Method

  • distance(HS): Method

  • distance(Dens): Method

  • distance(SO): Method

  • distance(LogEu): Method

  • distance(AffInv): Method

  • distance(Sphere): Method