Learn R Programming

manifold (version 0.1.2)

frechetMedian: Calculate the Fréchet median

Description

Calculate the Fréchet median

Usage

frechetMedian(mfd, X, ...)

# S3 method for default frechetMedian( mfd, X, mu0, weight = NULL, tol = 1e-09, maxit = 1000, alpha = 1, ... )

Value

A matrix with 1 column containing the Fréchet median

Arguments

mfd

A manifold object created by createM

X

A matrix with each column being a point on the manifold.

...

Passed into specific methods

mu0

A matrix of starting points. Each column corresponds to a starting point. If there are multiple columns, then a multistart algorithm is used.

weight

A vector of weights for the observations

tol

The threshold for determining convergence

maxit

Maximum iteration

alpha

The step size parameter. See Fletcher et al. (2008) CVPR

Methods (by class)

  • frechetMedian(default): Default method