Learn R Programming

manifold (version 0.1.2)

geodesicCurve: Obtain the geodesic curve

Description

Obtain the geodesic curve

Usage

geodesicCurve(mfd, p, h, t)

# S3 method for HS geodesicCurve(mfd, p, h, t)

# S3 method for Sphere geodesicCurve(mfd, p, h, t)

Value

A matrix of points lying on a geodesic. Different columns correspond to different time points

A matrix with each column representing a point on the manifold

Arguments

mfd

A class instance that represents the Riemannian manifold

p

The starting point of the geodesic curve

h

A matrix with each column representing a tangent vector. If there is only one tangent vector is supplied, then it is replicated to match the length of t

t

A vector, the time points where the curve is evaluated.

Methods (by class)

  • geodesicCurve(HS): Method

  • geodesicCurve(Sphere): Geodesic curve stating at a point

Details

The curve is \(\gamma(t)=\mathrm{Exp}_p(th)\)