Learn R Programming

manifold (version 0.1.2)

metric.Euclidean: Returns the Riemannian metric

Description

Returns the Riemannian metric

Usage

# S3 method for Euclidean
metric(mfd, p, U, V)

metric(mfd, p, U, V)

# S3 method for default metric(mfd, p = NULL, U, V)

# S3 method for HS metric(mfd, p, U, V)

# S3 method for Dens metric(mfd, p, U, V)

# S3 method for SO metric(mfd, p, U, V)

# S3 method for LogEu metric(mfd, p, U, V)

# S3 method for AffInv metric(mfd, p, U, V)

# S3 method for Sphere metric(mfd, p, U, V)

Value

A vector with n entries containing the metric values

Arguments

mfd

A manifold object created by createM

p

A vector containing the (single) base point on the manifold.

U, V

Matrices with n columns each containing a tangent vector. The metric of each pair of n columns is calculated.

Methods (by class)

  • metric(Euclidean): Method

  • metric(default): Method

  • metric(HS): Method

  • metric(Dens): Method

  • metric(SO): Method

  • metric(LogEu): Method

  • metric(AffInv): Method

  • metric(Sphere): Method