Learn R Programming

manifold (version 0.1.2)

norm.Euclidean: Norm on the tangent space induced by the Riemannian metric

Description

Norm on the tangent space induced by the Riemannian metric

Usage

# S3 method for Euclidean
norm(mfd, p, U)

norm(mfd, p, U)

# S3 method for default norm(mfd, p = NULL, U)

# S3 method for L2 norm(mfd, p, U)

# S3 method for HS norm(mfd, p, U)

# S3 method for Dens norm(mfd, p, U)

# S3 method for SO norm(mfd, p, U)

# S3 method for LogEu norm(mfd, p, U)

# S3 method for AffInv norm(mfd, p, U)

# S3 method for Sphere norm(mfd, p, U)

Value

A vector with n entries containing the norms of the tangent vectors

Arguments

mfd

A manifold object created by createM

p, U

Matrices with n columns. p stands for the base point(s) and U the tangent vector(s). The norm of each column in U is calculated w.r.t. the corresponding column in p.

Methods (by class)

  • norm(Euclidean): Method

  • norm(default): Method

  • norm(L2): Method

  • norm(HS): Method

  • norm(Dens): Method

  • norm(SO): Method

  • norm(LogEu): Method

  • norm(AffInv): Method

  • norm(Sphere): Method