Learn R Programming

manifold (version 0.1.2)

origin.Euclidean: Returns the origin of the manifold

Description

Each manifold defined in this package has been designated a more or less reasonable choice of origin.

Usage

# S3 method for Euclidean
origin(mfd, dimIntrinsic, ...)

origin(mfd, dimIntrinsic, ...)

# S3 method for L2 origin(mfd, dimIntrinsic, ...)

# S3 method for HS origin(mfd, dimIntrinsic, ...)

# S3 method for Dens origin(mfd, dimIntrinsic, ...)

# S3 method for SO origin(mfd, dimIntrinsic, ...)

# S3 method for SPD origin(mfd, dimIntrinsic, ...)

# S3 method for Sphere origin(mfd, dimIntrinsic, ...)

Value

A matrix with 1 column, a designation of the origin on the manifold

Arguments

mfd

A manifold object created by createM

dimIntrinsic

An integer for the intrinsic dimension

...

Passed into specific methods

Methods (by class)

  • origin(Euclidean): Method

  • origin(L2): Method

  • origin(HS): Method

  • origin(Dens): The uniform density

  • origin(SO): The origin has 1 in the first ambient coordinate and 0 otherwise.

  • origin(SPD): The origin is the identity matrix but vectorized.

  • origin(Sphere): The origin has 1 in the first ambient coordinate and 0 otherwise.