Riemannian logarithm map
# S3 method for Euclidean
rieLog(mfd, p, X, ...)rieLog(mfd, p, X, ...)
# S3 method for L2
rieLog(mfd, p, X, ...)
# S3 method for HS
rieLog(mfd, p, X, tol = 1e-07, ...)
# S3 method for Dens
rieLog(mfd, p, X, ...)
# S3 method for SO
rieLog(mfd, p, X, tol = 1e-10, ...)
# S3 method for LogEu
rieLog(mfd, p, X, ...)
# S3 method for AffInv
rieLog(mfd, p, X, ...)
# S3 method for Sphere
rieLog(mfd, p, X, tol = 1e-10, ...)
A matrix in which columns correspond to points on the tangent spaces
A manifold object created by createM
Matrices with n columns. The logarithm map of each column in X is calculated w.r.t. the corresponding column in p.
Passed into specific methods
Tolerance for `rieLog.SO`
rieLog(Euclidean): Method
rieLog(L2): Method
rieLog(HS): Method
rieLog(Dens): Method
rieLog(SO): Method
rieLog(LogEu): Method
rieLog(AffInv): Method
rieLog(Sphere): Method