tanVToCoord: Transform tangent vectors to their coordinates on the tangent space
Description
Transform the tangent vectors to coordinates w.r.t. the basis returned by [basisTan()]
Usage
tanVToCoord(mfd, p, V, ...)# S3 method for default
tanVToCoord(mfd, p, V, ...)
Value
A matrix in which each column correspond to a coordinate
Arguments
- mfd
A manifold object created by createM
- p
A vector for the base point
- V
A matrix or a vector containing the tangent vectors
- ...
Passed into specific methods