Calculate the Fréchet median
frechetMedian(mfd, X, ...)# S3 method for default
frechetMedian(
mfd,
X,
mu0,
weight = NULL,
tol = 1e-09,
maxit = 1000,
alpha = 1,
...
)
A matrix with 1 column containing the Fréchet median
A manifold object created by createM
A matrix with each column being a point on the manifold.
Passed into specific methods
A matrix of starting points. Each column corresponds to a starting point. If there are multiple columns, then a multistart algorithm is used.
A vector of weights for the observations
The threshold for determining convergence
Maximum iteration
The step size parameter. See Fletcher et al. (2008) CVPR
frechetMedian(default): Default method