Obtain the geodesic curve
geodesicCurve(mfd, p, h, t)# S3 method for HS
geodesicCurve(mfd, p, h, t)
# S3 method for Sphere
geodesicCurve(mfd, p, h, t)
A matrix of points lying on a geodesic. Different columns correspond to different time points
A matrix with each column representing a point on the manifold
A class instance that represents the Riemannian manifold
The starting point of the geodesic curve
A matrix with each column representing a tangent vector. If there is only one tangent vector is supplied, then it is replicated to match the length of t
A vector, the time points where the curve is evaluated.
geodesicCurve(HS): Method
geodesicCurve(Sphere): Geodesic curve stating at a point
The curve is \(\gamma(t)=\mathrm{Exp}_p(th)\)