Returns the Riemannian metric
# S3 method for Euclidean
metric(mfd, p, U, V)metric(mfd, p, U, V)
# S3 method for default
metric(mfd, p = NULL, U, V)
# S3 method for HS
metric(mfd, p, U, V)
# S3 method for Dens
metric(mfd, p, U, V)
# S3 method for SO
metric(mfd, p, U, V)
# S3 method for LogEu
metric(mfd, p, U, V)
# S3 method for AffInv
metric(mfd, p, U, V)
# S3 method for Sphere
metric(mfd, p, U, V)
A vector with n entries containing the metric values
A manifold object created by createM
A vector containing the (single) base point on the manifold.
Matrices with n columns each containing a tangent vector. The metric of each pair of n columns is calculated.
metric(Euclidean): Method
metric(default): Method
metric(HS): Method
metric(Dens): Method
metric(SO): Method
metric(LogEu): Method
metric(AffInv): Method
metric(Sphere): Method