Project data points in the ambient space onto the tangent space
# S3 method for Euclidean
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)projectTangent(mfd, p, X, projMatOnly, ...)
# S3 method for L2
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)
# S3 method for HS
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)
# S3 method for Dens
projectTangent(mfd, p, X, projMatOnly, ...)
# S3 method for SO
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)
# S3 method for SPD
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)
# S3 method for Sphere
projectTangent(mfd, p, X, projMatOnly = FALSE, ...)
A matrix in which columns correspond to points on the tangent spaces
A manifold object created by createM
A vector containing the base point on the manifold. Data X will be projected onto the tangent space of p.
A vector or a matrix containing the data points in terms of the coordinates in the ambient space.
Whether to only return the projection matrix (FALSE) or the projected data points (TRUE, the default)
Passed into specific methods
projectTangent(Euclidean): Method
projectTangent(L2): Method
projectTangent(HS): Method
projectTangent(Dens): Method
projectTangent(SO): Method
projectTangent(SPD): Method
projectTangent(Sphere): Method