Riemannian exponential map
# S3 method for Euclidean
rieExp(mfd, p, V, ...)rieExp(mfd, p, V, ...)
# S3 method for L2
rieExp(mfd, p, V, ...)
# S3 method for HS
rieExp(mfd, p, V, ...)
# S3 method for Dens
rieExp(mfd, p, V, ...)
# S3 method for SO
rieExp(mfd, p, V, tol = 1e-10, ...)
# S3 method for LogEu
rieExp(mfd, p, V, ...)
# S3 method for AffInv
rieExp(mfd, p, V, ...)
# S3 method for Sphere
rieExp(mfd, p, V, ...)
A matrix in which columns correspond to points on the manifold
A manifold object created by createM
Matrices with n columns. The exponential map of each column in V is calculated w.r.t. the corresponding column in p.
Passed into specific methods
Tolerance for `rieExp.SO`
rieExp(Euclidean): Method
rieExp(L2): Method
rieExp(HS): Method
rieExp(Dens): Method
rieExp(SO): Method
rieExp(LogEu): Method
rieExp(AffInv): Method
rieExp(Sphere): Method